var __awaiter = (this && this.__awaiter) || function (thisArg, _arguments, P, generator) {
    function adopt(value) { return value instanceof P ? value : new P(function (resolve) { resolve(value); }); }
    return new (P || (P = Promise))(function (resolve, reject) {
        function fulfilled(value) { try { step(generator.next(value)); } catch (e) { reject(e); } }
        function rejected(value) { try { step(generator["throw"](value)); } catch (e) { reject(e); } }
        function step(result) { result.done ? resolve(result.value) : adopt(result.value).then(fulfilled, rejected); }
        step((generator = generator.apply(thisArg, _arguments || [])).next());
    });
};
import { InstanceStateName } from '@aws-sdk/client-ec2';
import { createEc2Instance } from '../aws/ec2/create-ec2-instance.js';
import { createSecurityGroup } from '../aws/ec2/create-security-group.js';
import { getStringSsmParameter } from '../aws/ssm/get-ssm-parameter.js';
import { generateShortId } from '../common/short-id.js';
import * as bastionRoleOps from './create-bastion-role.js';
import { BASTION_INSTANCE_CLOUD_INIT } from './bastion-cloudinit.js';
import { BastionImageRetrievalError, BastionInlinePoliciesCreationError, BastionInstanceCreationError, BastionRoleCreationError, BastionSecurityGroupCreationError, } from './bastion-errors.js';
import { BASTION_INSTANCE_ID_TAG_NAME, BASTION_INSTANCE_IN_USE_TAG_NAME, BASTION_INSTANCE_NAME_PREFIX, BASTION_INSTANCE_PROFILE_PATH_PREFIX, BASTION_INSTANCE_SECURITY_GROUP_NAME_PREFIX, BASTION_INSTANCE_DEFAULT_INSTANCE_TYPE, BASTION_INSTANCE_DEFAULT_ASSIGN_PUBLIC_IP, } from './bastion.js';
export function createBastion({ vpcId, subnetId, instanceType, assignPublicIp, tags, hooks, }) {
    return __awaiter(this, void 0, void 0, function* () {
        const bastionId = generateShortId();
        const bastionImageId = yield getBastionImageId(hooks);
        const bastionRole = yield createBastionRole(bastionId, tags, hooks);
        const bastionSecurityGroup = yield createBastionSecurityGroup(bastionId, vpcId, tags, hooks);
        const bastionInstance = yield createBastionInstance(bastionId, bastionImageId, bastionRole, subnetId, bastionSecurityGroup, instanceType, assignPublicIp, tags, hooks);
        yield createBastionRoleInlinePolicies(bastionRole.name, bastionInstance.id, hooks);
        return {
            id: bastionId,
            instance: bastionInstance,
            state: InstanceStateName.running,
            securityGroupId: bastionSecurityGroup.id,
            securityGroupName: bastionSecurityGroup.name,
        };
    });
}
function getBastionImageId(hooks) {
    var _a, _b;
    return __awaiter(this, void 0, void 0, function* () {
        try {
            const parameterName = '/aws/service/ami-amazon-linux-latest/amzn2-ami-kernel-5.10-hvm-x86_64-gp2';
            (_a = hooks === null || hooks === void 0 ? void 0 : hooks.onRetrievingImageId) === null || _a === void 0 ? void 0 : _a.call(hooks);
            const bastionImageId = yield getStringSsmParameter({
                name: parameterName,
            });
            if (bastionImageId === undefined) {
                throw new Error(`Bastion image ID not found in SSM parameter ${parameterName}`);
            }
            (_b = hooks === null || hooks === void 0 ? void 0 : hooks.onImageIdRetrieved) === null || _b === void 0 ? void 0 : _b.call(hooks, bastionImageId);
            return bastionImageId;
        }
        catch (error) {
            throw new BastionImageRetrievalError(error);
        }
    });
}
function createBastionRole(bastionId, tags, hooks) {
    var _a, _b;
    return __awaiter(this, void 0, void 0, function* () {
        try {
            (_a = hooks === null || hooks === void 0 ? void 0 : hooks.onCreatingRole) === null || _a === void 0 ? void 0 : _a.call(hooks);
            const bastionRole = yield bastionRoleOps.createBastionRole({
                bastionId,
                tags,
            });
            (_b = hooks === null || hooks === void 0 ? void 0 : hooks.onRoleCreated) === null || _b === void 0 ? void 0 : _b.call(hooks, bastionRole.name);
            return bastionRole;
        }
        catch (error) {
            throw new BastionRoleCreationError(error);
        }
    });
}
function createBastionRoleInlinePolicies(bastionRoleName, bastionInstanceId, hooks) {
    var _a, _b;
    return __awaiter(this, void 0, void 0, function* () {
        try {
            (_a = hooks === null || hooks === void 0 ? void 0 : hooks.onCreatingInlinePolicies) === null || _a === void 0 ? void 0 : _a.call(hooks);
            yield bastionRoleOps.createBastionRoleInlinePolicies({
                bastionRoleName,
                bastionInstanceId,
            });
            (_b = hooks === null || hooks === void 0 ? void 0 : hooks.onInlinePoliciesCreated) === null || _b === void 0 ? void 0 : _b.call(hooks);
        }
        catch (error) {
            throw new BastionInlinePoliciesCreationError(error);
        }
    });
}
function createBastionSecurityGroup(bastionId, vpcId, tags, hooks) {
    var _a, _b;
    return __awaiter(this, void 0, void 0, function* () {
        try {
            (_a = hooks === null || hooks === void 0 ? void 0 : hooks.onCreatingSecurityGroup) === null || _a === void 0 ? void 0 : _a.call(hooks);
            const bastionSecurityGroup = yield createSecurityGroup({
                name: `${BASTION_INSTANCE_SECURITY_GROUP_NAME_PREFIX}-${bastionId}`,
                description: 'Identifies Basti instance and allows connection to the Internet',
                vpcId,
                tags,
                ingressRules: [],
            });
            (_b = hooks === null || hooks === void 0 ? void 0 : hooks.onSecurityGroupCreated) === null || _b === void 0 ? void 0 : _b.call(hooks, bastionSecurityGroup.id);
            return bastionSecurityGroup;
        }
        catch (error) {
            throw new BastionSecurityGroupCreationError(error);
        }
    });
}
function createBastionInstance(bastionId, bastionImageId, bastionRole, subnetId, bastionSecurityGroup, instanceType, assignPublicIp, tags, hooks) {
    var _a, _b;
    return __awaiter(this, void 0, void 0, function* () {
        try {
            (_a = hooks === null || hooks === void 0 ? void 0 : hooks.onCreatingInstance) === null || _a === void 0 ? void 0 : _a.call(hooks);
            const bastionInstance = yield createEc2Instance({
                name: `${BASTION_INSTANCE_NAME_PREFIX}-${bastionId}`,
                imageId: bastionImageId,
                instanceType: instanceType !== null && instanceType !== void 0 ? instanceType : BASTION_INSTANCE_DEFAULT_INSTANCE_TYPE,
                roleNames: [bastionRole.name],
                profilePathPrefix: BASTION_INSTANCE_PROFILE_PATH_PREFIX,
                subnetId,
                assignPublicIp: assignPublicIp !== null && assignPublicIp !== void 0 ? assignPublicIp : BASTION_INSTANCE_DEFAULT_ASSIGN_PUBLIC_IP,
                securityGroupIds: [bastionSecurityGroup.id],
                userData: BASTION_INSTANCE_CLOUD_INIT,
                requireIMDSv2: true,
                instanceTags: [
                    {
                        key: BASTION_INSTANCE_ID_TAG_NAME,
                        value: bastionId,
                    },
                    {
                        key: BASTION_INSTANCE_IN_USE_TAG_NAME,
                        value: new Date().toISOString(),
                    },
                ],
                tags,
            });
            (_b = hooks === null || hooks === void 0 ? void 0 : hooks.onInstanceCreated) === null || _b === void 0 ? void 0 : _b.call(hooks, bastionInstance.id);
            return bastionInstance;
        }
        catch (error) {
            throw new BastionInstanceCreationError(error);
        }
    });
}
//# sourceMappingURL=create-bastion.js.map