import inquirer from 'inquirer';
import { parseElasticacheMemcachedCacheNode, parseMemcachedCacheClusterResponse, } from '#src/aws/elasticache/parse-elasticache-memcached-response.js';
import { parseNodeGroupMemberResponse, parseNodeGroupResponse, } from '#src/aws/elasticache/parse-elasticache-redis-response.js';
import { fmt } from '#src/common/fmt.js';
export function toElasticacheChoices(redisClusters, redisCacheClusters, memcachedClusters, memcachedRawClusters, commandType) {
    if ((redisClusters[0] === undefined || redisClusters[0].length === 0) &&
        (redisClusters[1] === undefined || redisClusters[1].length === 0) &&
        memcachedClusters.length === 0)
        return [];
    return [
        new inquirer.Separator('Elasticache targets:'),
        ...toElasticacheClusterChoices(redisClusters, redisCacheClusters, commandType),
        ...toElasticacheMemcachedClusterChoices(memcachedClusters, memcachedRawClusters, commandType),
    ];
}
export function toElasticacheClusterChoices(clusters, cacheClusters, commandType) {
    if (clusters.length < 2 ||
        ((clusters[0] === undefined || clusters[0].length === 0) &&
            (clusters[1] === undefined || clusters[1].length === 0))) {
        return [];
    }
    return commandType === 'init'
        ? toInitElasticacheClusterChoices(clusters)
        : [
            new inquirer.Separator(' Redis clusters:'),
            ...toConnectElasticacheClusterChoices(clusters[0], cacheClusters, 'clusterModeEnabled'),
            ...toConnectElasticacheClusterChoices(clusters[1], cacheClusters, 'clusterModeDisabled'),
        ];
}
function toInitElasticacheClusterChoices(clusters) {
    return [
        new inquirer.Separator(' Redis clusters:'),
        ...clusters[0].map(cluster => toElasticacheClusterChoice(cluster)),
        ...clusters[1].map(cluster => toElasticacheClusterChoice(cluster)),
    ];
}
function toConnectElasticacheClusterChoices(clusters, cacheClusters, clustermMode) {
    if (clusters === undefined)
        return [];
    return clustermMode === 'clusterModeEnabled'
        ? clusters.flatMap(clusterModeEnabled => toElasticacheReplicationGroupChoises(clusterModeEnabled, cacheClusters))
        : clusters.flatMap(clusterModeDisabled => toClusterModeDisabledReplicationGroups(clusterModeDisabled));
}
function toElasticacheReplicationGroupChoises(replicationGroup, cacheClusters) {
    return [
        {
            name: '  ' + replicationGroup.identifier + ' - Configuration endpoint',
            value: { elasticacheRedisCluster: replicationGroup },
        },
        ...toClusterModeEnabledChoicesFromNodeGroups(replicationGroup, cacheClusters),
    ];
}
function toElasticacheClusterChoice(elasticacheRedisCluster) {
    return {
        name: '  ' + elasticacheRedisCluster.identifier,
        value: {
            elasticacheRedisCluster,
        },
    };
}
function toClusterModeEnabledChoicesFromNodeGroups(elasticacheReplicationGroup, elasticacheCacheCluster) {
    return elasticacheReplicationGroup.nodeGroups.flatMap(nodeGroup => toClusterModeEnabledChoicesFromNodeGroup(nodeGroup, elasticacheCacheCluster, elasticacheReplicationGroup.identifier));
}
function toClusterModeEnabledChoicesFromNodeGroup(elasticacheNodeGroup, elasticacheCacheCluster, replicationGroupId) {
    var _a;
    return elasticacheNodeGroup.NodeGroupMembers === undefined
        ? []
        : [
            new inquirer.Separator(`   Shard ${(_a = elasticacheNodeGroup.NodeGroupId) !== null && _a !== void 0 ? _a : ' '}`),
            ...elasticacheNodeGroup.NodeGroupMembers.map(member => {
                const cacheCluster = elasticacheCacheCluster.find(cache => {
                    return cache.identifier === member.CacheClusterId;
                });
                cacheCluster.replicationGroupId = replicationGroupId;
                return {
                    name: '    '.concat(member.CacheClusterId),
                    value: { elasticacheRedisCluster: cacheCluster },
                };
            }),
        ];
}
function toClusterModeDisabledReplicationGroups(elasticacheRedisCluster) {
    const NodeGroup = elasticacheRedisCluster.nodeGroups[0];
    if (NodeGroup.NodeGroupMembers === undefined ||
        NodeGroup.NodeGroupMembers.length === 0)
        return [];
    return [
        {
            name: '  ' +
                elasticacheRedisCluster.replicationGroupId.concat(' - Primary endpoint'),
            value: {
                elasticacheRedisCluster: parseNodeGroupResponse(NodeGroup, elasticacheRedisCluster.replicationGroupId),
            },
        },
        ...NodeGroup.NodeGroupMembers.map(member => {
            var _a;
            return {
                name: '   '.concat(member.CacheClusterId, ' - ', fmt.capitalize((_a = member.CurrentRole) !== null && _a !== void 0 ? _a : 'Node')),
                value: {
                    elasticacheRedisCluster: parseNodeGroupMemberResponse(member, elasticacheRedisCluster.replicationGroupId),
                },
            };
        }),
    ];
}
export function toElasticacheMemcachedClusterChoices(clusters, rawClusters, commandType) {
    if (clusters === undefined || clusters.length === 0)
        return [];
    return commandType === 'init'
        ? toInitElasticacheMemcachedChoices(clusters)
        : [
            new inquirer.Separator(' Memcached clusters:'),
            ...toConnectElasticacheMemcachedClusterChoices(rawClusters),
        ];
}
function toInitElasticacheMemcachedChoices(clusters) {
    return [
        new inquirer.Separator(' Memcached clusters:'),
        ...clusters.map(cluster => toElasticacheMemcachedClusterChoice(cluster, 'init')),
    ];
}
function toElasticacheMemcachedClusterChoice(elasticacheMemcachedCluster, commandType) {
    return commandType === 'init'
        ? {
            name: '  ' + elasticacheMemcachedCluster.identifier,
            value: {
                elasticacheMemcachedCluster,
            },
        }
        : {
            name: '  ' +
                elasticacheMemcachedCluster.identifier.concat(' - Configuration endpoint'),
            value: {
                elasticacheMemcachedCluster,
            },
        };
}
function toElasticacheMemcachedNodeChoice(elasticacheMemcachedCluster) {
    return {
        name: '   ' +
            elasticacheMemcachedCluster.clusterId +
            '-' +
            elasticacheMemcachedCluster.identifier,
        value: {
            elasticacheMemcachedCluster,
        },
    };
}
function toConnectElasticacheMemcachedClusterChoices(cacheClusters) {
    if (cacheClusters === undefined)
        return [];
    return cacheClusters.flatMap(memCluster => toMemcachedCluster(memCluster));
}
function toMemcachedCluster(memCluster) {
    return [
        toElasticacheMemcachedClusterChoice(parseMemcachedCacheClusterResponse(memCluster), 'connect'),
        ...memCluster.CacheNodes.map(cacheNode => toElasticacheMemcachedNodeChoice(parseElasticacheMemcachedCacheNode(memCluster, memCluster.CacheClusterId.concat('-', cacheNode.CacheNodeId)))),
    ];
}
//# sourceMappingURL=to-elasticache-choises.js.map