var __awaiter = (this && this.__awaiter) || function (thisArg, _arguments, P, generator) {
    function adopt(value) { return value instanceof P ? value : new P(function (resolve) { resolve(value); }); }
    return new (P || (P = Promise))(function (resolve, reject) {
        function fulfilled(value) { try { step(generator.next(value)); } catch (e) { reject(e); } }
        function rejected(value) { try { step(generator["throw"](value)); } catch (e) { reject(e); } }
        function step(result) { result.done ? resolve(result.value) : adopt(result.value).then(fulfilled, rejected); }
        step((generator = generator.apply(thisArg, _arguments || [])).next());
    });
};
import fs from 'node:fs';
import path from 'node:path';
import url from 'node:url';
import { spawnProcess } from '../common/child-process.js';
import { SessionManagerPluginExitError, SessionManagerPluginPortInUseError, SessionManagerPluginNonInstalledError, SessionManagerPluginTimeoutError, } from './session-errors.js';
export function startSessionManagerPluginProcess({ sessionDescriptor, hooks, }) {
    return __awaiter(this, void 0, void 0, function* () {
        const sessionManager = spawnPluginProcess(sessionDescriptor);
        return yield new Promise((resolve, reject) => {
            let isStarted = false;
            sessionManager.onLine(line => {
                if (isPortOpened(line)) {
                    isStarted = true;
                    startExitListener(sessionManager, hooks);
                    resolve();
                }
            });
            setTimeout(() => {
                if (!isStarted) {
                    sessionManager.kill();
                    reject(new SessionManagerPluginTimeoutError(sessionManager.collectAllOutput()));
                }
            }, 30000).unref();
            sessionManager.onLine(line => isPortInUse(line) && reject(new SessionManagerPluginPortInUseError()));
            sessionManager.onExit(exitDescription => reject(new SessionManagerPluginExitError(exitDescription)));
            sessionManager.process.on('error', error => reject(parseProcessError(error)));
        });
    });
}
function spawnPluginProcess(sessionDescriptor) {
    // Session Manager Plugin arguments could be found here:
    // https://github.com/aws/session-manager-plugin/blob/916aa5c1c241967baaf20a0f3edcde44a45e4dfb/src/sessionmanagerplugin/session/session.go#L162
    const args = [
        JSON.stringify(sessionDescriptor.response),
        sessionDescriptor.region,
        'StartSession',
        '',
        JSON.stringify(sessionDescriptor.request),
        sessionDescriptor.endpoint,
    ];
    const binaryPath = getPluginBinaryPath();
    return spawnProcess(binaryPath, args);
}
function startExitListener(sessionManager, hooks) {
    sessionManager.onExit(exitDescription => {
        var _a, _b;
        if (exitDescription.reason === 0) {
            (_a = hooks === null || hooks === void 0 ? void 0 : hooks.onExit) === null || _a === void 0 ? void 0 : _a.call(hooks, exitDescription);
        }
        else {
            (_b = hooks === null || hooks === void 0 ? void 0 : hooks.onErrorExit) === null || _b === void 0 ? void 0 : _b.call(hooks, new SessionManagerPluginExitError(exitDescription));
        }
    });
}
function parseProcessError(error) {
    return error.code === 'ENOENT'
        ? new SessionManagerPluginNonInstalledError()
        : error;
}
function isPortOpened(line) {
    return line.toLowerCase().includes('waiting for connection');
}
function isPortInUse(line) {
    return line.toLowerCase().includes('address already in use');
}
function getPluginBinaryPath() {
    const rootDir = path.resolve(path.dirname(url.fileURLToPath(import.meta.url)), '..', '..', '..');
    const devDepsDir = path.resolve(rootDir, 'deps');
    const nodeModulesDir = path.resolve(rootDir, 'node_modules');
    const outerDir = path.resolve(rootDir, '..');
    const devPluginBinaryPath = getDepPluginBinaryPath(devDepsDir);
    const nodeModulesPluginBinaryPath = getDepPluginBinaryPath(nodeModulesDir);
    const outerPluginBinaryPath = getDepPluginBinaryPath(outerDir);
    return fs.existsSync(devPluginBinaryPath)
        ? devPluginBinaryPath
        : fs.existsSync(nodeModulesPluginBinaryPath)
            ? nodeModulesPluginBinaryPath
            : fs.existsSync(outerPluginBinaryPath)
                ? outerPluginBinaryPath
                : 'session-manager-plugin';
}
function getDepPluginBinaryPath(depsDir) {
    return path.resolve(depsDir, `basti-session-manager-binary-${process.platform}-${process.arch}`, 'session-manager-plugin');
}
//# sourceMappingURL=start-session-manager-plugin-process.js.map